"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const xrp_codec_1 = require("./xrp-codec");
exports.codec = xrp_codec_1.codec;
exports.encodeSeed = xrp_codec_1.encodeSeed;
exports.decodeSeed = xrp_codec_1.decodeSeed;
exports.encodeAccountID = xrp_codec_1.encodeAccountID;
exports.decodeAccountID = xrp_codec_1.decodeAccountID;
exports.encodeNodePublic = xrp_codec_1.encodeNodePublic;
exports.decodeNodePublic = xrp_codec_1.decodeNodePublic;
exports.isValidAddress = xrp_codec_1.isValidAddress // Check whether a classic address (r...) is valid
;
const assert = require("assert");
const PREFIX_BYTES = {
    MAIN: Buffer.from([0x05, 0x44]),
    TEST: Buffer.from([0x04, 0x93]) // 4, 147
};
function encodeXAddress(classicAddress, tag, test) {
    const MAX_32_BIT_UNSIGNED_INT = 4294967295;
    const flag = tag === false ? 0 : tag <= MAX_32_BIT_UNSIGNED_INT ? 1 : 2;
    if (flag === 2) {
        throw new Error('Invalid tag');
    }
    const accountId = xrp_codec_1.decodeAccountID(classicAddress);
    if (tag === false) {
        tag = 0;
    }
    const bytes = Buffer.concat([
        test ? PREFIX_BYTES.TEST : PREFIX_BYTES.MAIN,
        accountId,
        Buffer.from([
            flag,
            tag & 0xff,
            (tag >> 8) & 0xff,
            (tag >> 16) & 0xff,
            (tag >> 24) & 0xff,
            0, 0, 0, 0 // four zero bytes (reserved for 64-bit tags)
        ])
    ]);
    const xAddress = xrp_codec_1.codec.encodeChecked(bytes);
    return xAddress;
}
exports.encodeXAddress = encodeXAddress;
function decodeXAddress(xAddress) {
    const decoded = xrp_codec_1.codec.decodeChecked(xAddress);
    const test = (() => {
        const decodedPrefix = decoded.slice(0, 2);
        if (PREFIX_BYTES.MAIN.equals(decodedPrefix)) {
            return false;
        }
        else if (PREFIX_BYTES.TEST.equals(decodedPrefix)) {
            return true;
        }
        else {
            throw new Error('Invalid X-address: bad prefix');
        }
    })();
    const classicAddress = xrp_codec_1.encodeAccountID(decoded.slice(2, 22));
    const flag = decoded[22];
    if (flag >= 2) {
        // No support for 64-bit tags at this time
        throw new Error('Unsupported X-address');
    }
    const tag = (() => {
        if (flag === 1) {
            // Little-endian to big-endian
            return decoded[23] + decoded[24] * 0x100 + decoded[25] * 0x10000 + decoded[26] * 0x1000000;
        }
        assert.strictEqual(flag, 0, 'flag must be zero to indicate no tag');
        assert.ok(Buffer.from('0000000000000000', 'hex').equals(decoded.slice(23, 23 + 8)), 'remaining bytes must be zero');
        return false;
    })();
    return {
        classicAddress,
        tag,
        test
    };
}
exports.decodeXAddress = decodeXAddress;
function isValidXAddress(xAddress) {
    try {
        decodeXAddress(xAddress);
    }
    catch (e) {
        return false;
    }
    return true;
}
exports.isValidXAddress = isValidXAddress;
//# sourceMappingURL=index.js.map