/// <reference types="node" />
declare type Sequence = number[] | Buffer | Uint8Array;
/**
 * Check whether two sequences (e.g. arrays of numbers) are equal.
 *
 * @param arr1 One of the arrays to compare.
 * @param arr2 The other array to compare.
 */
export declare function seqEqual(arr1: Sequence, arr2: Sequence): boolean;
/**
* Concatenate all `arguments` into a single array. Each argument can be either
* a single element or a sequence, which has a `length` property and supports
* element retrieval via sequence[ix].
*
* > concatArgs(1, [2, 3], Buffer.from([4,5]), new Uint8Array([6, 7]));
*  [1,2,3,4,5,6,7]
*
* @returns {number[]} Array of concatenated arguments
*/
export declare function concatArgs(...args: (number | Sequence)[]): number[];
export {};
